# Release Note: SuperSocket 2.0.2-beta.1

## Overview
SuperSocket 2.0.2-beta.1 is a beta release that enhances the flexibility of pipeline filters by removing the constraint requiring a default constructor. This change significantly improves dependency injection support for pipeline filters across the framework.

## Key Improvements

### Enhanced Dependency Injection Support for Pipeline Filters
- Removed the constraint requiring pipeline filters to have a parameterless constructor (`new()` constraint)
- This change enables pipeline filters to receive dependencies through constructor injection
- Modified all relevant method signatures across the framework to support this new flexibility

### Affected Components
The `new()` constraint was removed from the following interfaces and methods:

1. In `ISuperSocketHostBuilder<TReceivePackage>` interface:
   - `UsePipelineFilter<TPipelineFilter>()` method

2. In `HostBuilderExtensions` class:
   - `AsSuperSocketHostBuilder<TReceivePackage, TPipelineFilter>()` method

3. In `MultipleServerHostBuilder` class:
   - `AddServer<TReceivePackage, TPipelineFilter>()` method
   - `AddServer<TSuperSocketService, TReceivePackage, TPipelineFilter>()` method

4. In `SuperSocketHostBuilder` class and static methods:
   - `UsePipelineFilter<TPipelineFilter>()` method
   - `Create<TReceivePackage, TPipelineFilter>()` methods

## Compatibility
This change is backward compatible with existing code. Pipeline filters with default constructors will continue to work as before, but now you can also create pipeline filters that require dependencies to be injected.

## Example Usage
With this change, you can now create pipeline filters that require dependencies:

```csharp
public class MyPipelineFilter : IPipelineFilter<TextPackageInfo>
{
    private readonly ILogger<MyPipelineFilter> _logger;
    private readonly IConfiguration _configuration;

    // Constructor with dependencies - now supported!
    public MyPipelineFilter(ILogger<MyPipelineFilter> logger, IConfiguration configuration)
    {
        _logger = logger;
        _configuration = configuration;
    }

    // Implementation details...
}

// Register and use the filter
hostBuilder.AsSuperSocketHostBuilder<TextPackageInfo, MyPipelineFilter>();
```

## Release Status
This is a beta release intended for testing. Please report any issues you encounter on the GitHub repository.

## Contributors
- Kerry Jiang

## Links
- GitHub Repository: https://github.com/kerryjiang/SuperSocket
- Documentation: https://docs.supersocket.net/
- NuGet Packages: https://www.nuget.org/packages?q=SuperSocket
